homogeneity: Calculate within-cluster homogeneity

View source: R/evalClusterQuality.R

homogeneityR Documentation

Calculate within-cluster homogeneity

Description

Within a group of N consumers, the Homogeneity index lies between 1/N (no homogeneity) to 1 (perfect homogeneity).

Usage

homogeneity(X)

Arguments

X

three-way array; the I \times J \times M array has I assessors, J products, M attributes where CATA data have values 0 (not checked) and 1 (checked)

Value

homogeneity index

Author(s)

J.C. Castura

References

Llobell, F., Cariou, V., Vigneau, E., Labenne, A., & Qannari, E.M. (2019). A new approach for the analysis of data and the clustering of subjects in a CATA experiment. Food Quality and Preference, 72, 31-39, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.foodqual.2018.09.006")}

Examples

# homogeneity index for the first 7 consumers on the first 6 attributes
homogeneity(bread$cata[1:7,,1:6])

cata documentation built on Aug. 1, 2026, 1:06 a.m.

Related to homogeneity in cata...