plift: Penalty-Lift Analysis

View source: R/plift.R

pliftR Documentation

Penalty-Lift Analysis

Description

Penalty-Lift analysis for CATA variables, which is the difference between the average hedonic response when CATA attribute is checked vs. the average hedonic response when CATA attribute is not checked.

Usage

plift(X, Y, drop = FALSE)

Arguments

X

either a matrix of CATA data with I consumers (rows) and J products (columns) or an array of CATA data with I consumers, J products, and M attributes.

Y

matrix of hedonic data with I consumers (rows) and J products (columns)

drop

default (FALSE) uses all assessor data; TRUE drops assessors on any attributes where they give identical responses to all products.

Value

Penalty lift per attribute, with counts and averages.

Author(s)

J.C. Castura

References

Meyners, M., Castura, J.C., & Carr, B.T. (2013). Existing and new approaches for the analysis of CATA data. Food Quality and Preference, 30, 309-319, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.foodqual.2013.06.010")}

Examples

# penalty lift, based only on the first 12 consumers

# for the first attribute ("Fresh")
plift(bread$cata[1:12,,1], bread$liking[1:12, ]) 

# for the first 3  attributes with counts and averages
plift(bread$cata[1:12,,1:3], bread$liking[1:12, ]) 
 
# same, dropping assessors who give the same response on all products
plift(bread$cata[1:12,,1:3], bread$liking[1:12, ], drop = TRUE) 

cata documentation built on Aug. 1, 2026, 1:06 a.m.

Related to plift in cata...